Enum oracle::OracleType [−][src]
pub enum OracleType {
Varchar2(u32),
NVarchar2(u32),
Char(u32),
NChar(u32),
Rowid,
Raw(u32),
BinaryFloat,
BinaryDouble,
Number(u8, i8),
Float(u8),
Date,
Timestamp(u8),
TimestampTZ(u8),
TimestampLTZ(u8),
IntervalDS(u8, u8),
IntervalYM(u8),
CLOB,
NCLOB,
BLOB,
BFILE,
RefCursor,
Boolean,
Object(ObjectType),
Long,
LongRaw,
Int64,
UInt64,
}Oracle data type
Variants
Varchar2(u32)VARCHAR2(size)
NVarchar2(u32)NVARCHAR2(size)
Char(u32)CHAR(size)
NChar(u32)NCHAR(size)
RowidROWID
Raw(u32)RAW(size)
BinaryFloatBINARY_FLOAT
IEEE 754 single-precision (32-bit) floating-point number
BinaryDoubleBINARY_DOUBLE
IEEE 754 double-precision (64-bit) floating-point number
Number(u8, i8)NUMBER(precision, scale)
precision is between 0 and 38. When it is 0, its actual precision is
38 and (precision, scale) is omitted in text represention.
scale is between -87 and 127. When it is 0, this is represented
as NUMBER(precision) in text.
Float(u8)FLOAT(precision)
This is a subtype of NUMBER. The internal format is same with NUMBER, which means that numbers are stored as decimal not as binary. Use BINARY_DOUBLE or BINARY_FLOAT to store f64 or f32 rust types.
precision is between 0 and 126. When it is 126, (precision) is
omitted in text represention.
DateDATE data type
Timestamp(u8)TIMESTAMP(fsprec)
Timestamp data type without time zone.
fsprec is fractional seconds precision between 0 and 9. When it is
6, (fsprec) is omitted in text represention.
TimestampTZ(u8)TIMESTAMP(fsprec) WITH TIME ZONE
Timestamp data type with time zone.
fsprec is fractional seconds precision between 0 and 9. When it is
6, (fsprec) is omitted in text represention.
TimestampLTZ(u8)TIMESTAMP(fsprec) WITH LOCAL TIME ZONE
Timestamp data type in local session time zone. Clients in different session time zones retrieves different timestamp.
fsprec is fractional seconds precision between 0 and 9. When it is
6, (fsprec) is omitted in text represention.
IntervalDS(u8, u8)INTERVAL DAY(lfprec) TO SECOND(fsprec)
lfprec is leading field precision between 0 and 9. When it is 2,
(lfprec) is omitted in text represention.
fsprec is fractional seconds precision between 0 and 9. When it is
6, (fsprec) is omitted in text represention.
IntervalYM(u8)INTERVAL YEAR(lfprec) TO MONTH
lfprec is leading field precision between 0 and 9. When it is 2,
(lfprec) is omitted in text represention.
CLOBCLOB
NCLOBNCLOB
BLOBBLOB
BFILEBFILE
RefCursorREF CURSOR (not supported)
BooleanBOOLEAN (not supported)
Object(ObjectType)Object
LongLONG
LongRawLONG RAW
Int64Integer type in Oracle object type attributes. This will be renamed to Integer in future.
UInt64Not an Oracle type, used only internally to bind/define values as u64